@@ -2,7 +2,7 @@ use alloc::vec::Vec;
 use core::mem;
 use core::ops::Range;
 
-use super::buffers::{Coalescer, Delocator, Locator};
+use super::buffers::{BufferProgress, Coalescer, Delocator, Locator};
 use crate::error::InvalidMessage;
 use crate::msgs::codec::{u24, Codec};
 use crate::msgs::message::InboundPlainMessage;
@@ -73,6 +73,11 @@ impl HandshakeDeframer {
         }
     }
 
+    /// Returns a `BufferProgress` that skips over unprocessed handshake data.
+    pub(crate) fn progress(&self) -> BufferProgress {
+        BufferProgress::new(self.outer_discard)
+    }
+
     /// Do we have a message ready? ie, would `iter().next()` return `Some`?
     pub(crate) fn has_message_ready(&self) -> bool {
         match self.spans.first() {
@@ -298,7 +303,7 @@ pub(crate) struct HandshakeIter<'a, 'b> {
     index: usize,
 }
 
-impl<'a, 'b> Iterator for HandshakeIter<'a, 'b> {
+impl<'b> Iterator for HandshakeIter<'_, 'b> {
     type Item = (InboundPlainMessage<'b>, usize);
 
     fn next(&mut self) -> Option<Self::Item> {
